@@ -6,10 +6,16 @@ MyApp->setup_plugins([qw/
 /]);
 
 MyApp->config(
-  'Plugin::CSRFToken' => { default_secret=>'changeme', auto_check => 1 }
-);
+  'Plugin::CSRFToken' => {
+    'session_key' => '_csrf_token2',
+    'form_id_param_key' => 'csrf_form_id2',
+    'token_param_key' => 'csrf_token2',
+    'max_age' => 8888,
+    'default_secret' => 'begin',
 
-sub sessionid { 23123123123 }
+    'auto_check' => 1,
+  }
+);
 
 my %session = ();
 sub session {
